.. _android:

Android string resources
************************

:wp:`Android <Android_%28operating_system%29>` programs make use of localisable
string resources.

:guilabel:`Mobile Kotlin resources` are supported as a variant of this format.

.. note:: The toolkit supports this format, but still doesn't provide any
   converter.


.. _android#references:

References
==========

* Android `Resource files reference
  <http://developer.android.com/guide/topics/resources/resources-i18n.html>`_
* Android `String resources reference
  <http://developer.android.com/guide/topics/resources/available-resources.html#stringresources>`_
* `Localizing Android Applications <http://www.linux-mag.com/id/7794>`_ tutorial
* Reference for `translatable attribute
  <http://tools.android.com/recent/non-translatablestrings>`_
* `Mobile Kotlin resources <https://github.com/icerockdev/moko-resources>`_
